<?php
class SettingsPage
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
        add_action('admin_menu', [$this, 'spyrit_venio_page']);
        add_action('admin_init', [$this, 'spyrit_venio_page_init']);
        add_action('admin_print_styles', [$this, 'spyrit_venio_load_plugin_css']);
    }

    public function spyrit_venio_load_plugin_css()
    {
        wp_enqueue_style('SV_backoffice', plugin_dir_url(__FILE__) . '../assets/spyrit-venio-admin.css');
    }

    /**
     * Add options page
     */
    public function spyrit_venio_page()
    {
        add_menu_page(
            'Venio',
            'Venio',
            'manage_options',
            'spyrit-venio-options',
            [$this, 'spyrit_venio_admin_page'],
            plugins_url('../assets/img/venio-icon.ico', __FILE__)
        );
    }

    /**
     * Options page callback
     */
    public function spyrit_venio_admin_page()
    {

        if (isset($_GET['page']) && $_GET['page'] == 'spyrit-venio-options' && isset($_GET['sync'])) {
            try {
                $api = new \SPYRIT_VENIO\Api();
                $api->getEvents(null, null, true);
            } catch (Exception $e) {
            }
        }

        $this->options = get_option('spyrit_venio_config'); ?>
        <div class="wrap">
            <h1>
                <img src="<?= plugin_dir_url(__FILE__) ?>../assets/img/logo-venio.svg" alt="Logo de VENIO">
                Venio
            </h1>
            <div class="notices-wrap"><?php do_action('admin_notices') ?></div>
            <div class="container">
                <form method="post" action="options.php">
                    <?php
                        settings_fields('spyrit-venio-group');
                        do_settings_sections('spyrit-venio-options');
                        submit_button();
                        ?>
                </form>
                <form method="POST" action="<?php echo $_SERVER['REQUEST_URI'] ?>&sync">
                    <h2>Récupération des événements</h2>
                    <div class="api-call">
                        <?php submit_button('Forcer la récupération', 'large', 'sync', true, '') ?>
                        <?php if (get_option('spyrit_venio_api_last_call')): ?>
                            <p style="margin-top: 10px;">Dernière récupération : <strong><?= get_option('spyrit_venio_api_last_call') ?></strong></p>
                        <?php endif; ?>
                    </div>
                </form>
                <div class="using">
                    <h2>Comment utiliser l'extension Venio sur votre site internet ?</h2>
                    <h3>Insérez le shortcode dans vos pages / articles WordPress</h3>
                    <p class="shortcode">[venio-events]</p>
                    <p>
                        Affiche un module de recherche qui liste vos événements en fonction des critères recherchés.<br />
                        Options disponibles&nbsp;:
                    </p>
                    <ul>
                        <li>
                            <strong>institution</strong> (non requis)&nbsp;: slug de l'institution des événements.<br>
                            <em>Exemple d'intégration&nbsp;:</em> <strong>[venio-events institution=mon-institution]</strong>
                        </li>
                    </ul>
                </div>
                <div class="using">
                    <h2>Comment ça marche ?</h2>
                    <h3>Page "single"</h3>
                    <p>
                        Un URL est disponible pour chacun de vos événements, sous la forme suivante :<br>
                        https://votresite.fr/<strong>v-evenement</strong>/<strong>slug-de-votre-evenement</strong>
                    </p>
                    <p>Cette URL est générée à la volée, en fonction des événements connus par le site via l'API Venio.</p>
                    <h3>Le cache</h3>
                    <p>La connexion avec VENIO et l'appel de vos événements est régulée par un cache sur votre site WordPress.</p>
                    <p>La durée de vie du cache est d'une heure (3600 secondes), toutes les heures, votre site WordPress fait un nouvel appel à VENIO pour récupérer et afficher vos événements.</p>
                    <p>À tout moment, vous pouvez forcer la récupération des événements (le renouvellement du cache) en appuyant sur le bouton "Forcer la récupération".</p>

                </div>
                <div class="copy">
                    Venio version <?= VENIO_VERSION ?><br>
                    Développé par <a href="https://www.spyrit.net" title="Accéder au site de SPYRIT" target="_blank">Spyrit systèmes d'information</a>
                </div>
            </div>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function spyrit_venio_page_init()
    {
        register_setting(
            'spyrit-venio-group',
            'spyrit_venio_config'
        );

        add_settings_section(
            'spyrit-venio-section-api',
            'API',
            null,
            'spyrit-venio-options'
        );

        add_settings_field(
            'spyrit-venio-institutions',
            'Institutions',
            [$this, 'spyrit_venio_institutions_callback'],
            'spyrit-venio-options',
            'spyrit-venio-section-api'
        );
    }

    public function spyrit_venio_institutions_callback()
    {
        printf(
            '<input type="text" id="institutions" name="spyrit_venio_config[institutions]" value="%s" placeholder="Institutions, séparées par une virgule" />',
            isset($this->options['institutions']) ? esc_attr($this->options['institutions']) : ''
        );
    }
}

if (is_admin()) {
    $settings_page = new SettingsPage();
}
